Abstract base class for instances that evaluate an objective function. This class provides common functionality shared between optimization (OptimInstance) and other evaluation patterns (e.g., active learning).
objective(Objective)
Objective function of the instance.
search_space(paradox::ParamSet)
Specification of the search space for the Optimizer.
terminatorTerminator
Termination criterion of the optimization.
archive(Archive)
Contains all performed function calls of the Objective.
label(character(1))
Label for this object.
Can be used in tables, plot and text output instead of the ID.
man(character(1))
String in the format [pkg]::[topic] pointing to a manual page for this object.
The referenced help package can be opened via method $help().
is_terminated(logical(1))
Whether the terminator says we should stop.
n_evals(integer(1))
Number of evaluations performed.
new()Creates a new instance of this R6 class.
EvalInstance$new(
objective,
search_space,
terminator,
archive,
label = NA_character_,
man = NA_character_
)objective(Objective)
Objective function.
search_space(paradox::ParamSet)
Specifies the search space for the Optimizer. The paradox::ParamSet
describes either a subset of the domain of the Objective or it describes
a set of parameters together with a trafo function that transforms values
from the search space to values of the domain. Depending on the context, this
value defaults to the domain of the objective.
terminatorTerminator
Termination criterion.
archive(Archive).
label(character(1))
Label for this object.
Can be used in tables, plot and text output instead of the ID.
man(character(1))
String in the format [pkg]::[topic] pointing to a manual page for this object.
The referenced help package can be opened via method $help().
...(ignored).
...(ignored).
clear()Clear all evaluation results from archive.
EvalInstance$clear()
clone()The objects of this class are cloneable with this method.
EvalInstance$clone(deep = FALSE)deepWhether to make a deep clone.
EvalInstance contains the core components needed for any objective
evaluation loop:
An Objective to evaluate
A search space defining valid inputs
An Archive storing evaluation history
A Terminator defining stopping conditions
Subclasses add specific functionality:
OptimInstance: Result tracking, optimization-specific methods
External packages may define their own subclasses