OptimizerBatch: Batch Optimizer

OptimizerBatchR Documentation

Batch Optimizer

Description

Abstract OptimizerBatch class that implements the base functionality each OptimizerBatch subclass must provide. A OptimizerBatch object describes the optimization strategy. A OptimizerBatch object must write its result to the ⁠$assign_result()⁠ method of the OptimInstance at the end in order to store the best point and its estimated performance vector.

Progress Bars

⁠$optimize()⁠ supports progress bars via the package progressr combined with a Terminator. Simply wrap the function in progressr::with_progress() to enable them. We recommend to use package progress as backend; enable with progressr::handlers("progress").

Super class

Optimizer -> OptimizerBatch

Methods

Public methods

Inherited methods

OptimizerBatch$optimize()

Performs the optimization and writes optimization result into OptimInstanceBatch. The optimization result is returned but the complete optimization path is stored in ArchiveBatch of OptimInstanceBatch.

Usage
OptimizerBatch$optimize(inst)
Arguments
inst

(OptimInstanceBatch).

Returns

data.table::data.table.


OptimizerBatch$clone()

The objects of this class are cloneable with this method.

Usage
OptimizerBatch$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

See Also

OptimizerBatchDesignPoints, OptimizerBatchGridSearch, OptimizerBatchRandomSearch


bbotk documentation built on July 17, 2026, 5:07 p.m.