is_dominated: Calculate which points are dominated

View source: R/helper.R

is_dominatedR Documentation

Calculate which points are dominated

Description

Returns which points from a set are dominated by another point in the set. See moocore::is_nondominated() for details about the implementation. Points that are equal to each other are all considered non-dominated, i.e. weakly dominated points are kept.

Usage

is_dominated(ymat)

Arguments

ymat

(matrix())
A numeric matrix. Each column (!) contains one point.

Value

logical() with TRUE if a point (column of ymat) is dominated.

See Also

moocore::is_nondominated()


bbotk documentation built on July 17, 2026, 5:07 p.m.