Learn R Programming

bbotk (version 1.12.0)

mlr_terminators_none: None Terminator

Description

Mainly useful for optimization algorithms where the stopping is inherently controlled by the algorithm itself (e.g. OptimizerBatchGridSearch).

Arguments

Dictionary

This Terminator can be instantiated via the dictionary mlr_terminators or with the associated sugar function trm():

mlr_terminators$get("none")
trm("none")

Super class

Terminator -> TerminatorNone

Methods

Inherited methods

TerminatorNone$new()

Creates a new instance of this R6 class.

Usage

TerminatorNone$new()


TerminatorNone$is_terminated()

Is TRUE iff the termination criterion is positive, and FALSE otherwise.

Usage

TerminatorNone$is_terminated(archive)

Arguments

archive

(Archive).

Returns

logical(1).


TerminatorNone$clone()

The objects of this class are cloneable with this method.

Usage

TerminatorNone$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

See Also

Other Terminator: Terminator, mlr_terminators, mlr_terminators_clock_time, mlr_terminators_combo, mlr_terminators_evals, mlr_terminators_perf_reached, mlr_terminators_run_time, mlr_terminators_stagnation, mlr_terminators_stagnation_batch, mlr_terminators_stagnation_hypervolume