Class to terminate the optimization after the performance stagnates, i.e.
does not improve more than threshold over the last iters iterations.
This Terminator can be instantiated via the
dictionary mlr_terminators or with the associated
sugar function trm():
mlr_terminators$get("stagnation")
trm("stagnation")
itersinteger(1)
Number of iterations to evaluate the performance improvement on, default
is 10.
thresholdnumeric(1)
If the improvement is less than threshold, optimization is stopped,
default is 0.
bbotk::Terminator -> TerminatorStagnation
is_terminated()Is TRUE iff the termination criterion is positive, and FALSE
otherwise.
TerminatorStagnation$is_terminated(archive)archive(Archive).
logical(1).
clone()The objects of this class are cloneable with this method.
TerminatorStagnation$clone(deep = FALSE)deepWhether to make a deep clone.
Other Terminator:
Terminator,
mlr_terminators_clock_time,
mlr_terminators_combo,
mlr_terminators_evals,
mlr_terminators_none,
mlr_terminators_perf_reached,
mlr_terminators_run_time,
mlr_terminators_stagnation_batch,
mlr_terminators
TerminatorStagnation$new()
trm("stagnation", iters = 5, threshold = 1e-5)
Run the code above in your browser using DataLab