mlr_terminators_stagnation_hypervolume: Stagnation Hypervolume Terminator

mlr_terminators_stagnation_hypervolumeR Documentation

Stagnation Hypervolume Terminator

Description

Class to terminate the optimization after the hypervolume stagnates, i.e. does not improve more than threshold over the last iters iterations. The hypervolume is computed using moocore::hypervolume(). The reference point is the maximum of each objective over all evaluations.

Dictionary

This Terminator can be instantiated via the dictionary mlr_terminators or with the associated sugar function trm():

mlr_terminators$get("stagnation_hypervolume")
trm("stagnation_hypervolume")

Parameters

iters

integer(1)
Number of iterations to evaluate the performance improvement on, default is 10.

threshold

numeric(1)
If the improvement is less than threshold, optimization is stopped, default is 0.

Super class

Terminator -> TerminatorStagnationHypervolume

Methods

Public methods

Inherited methods

TerminatorStagnationHypervolume$new()

Creates a new instance of this R6 class.

Usage
TerminatorStagnationHypervolume$new()

TerminatorStagnationHypervolume$is_terminated()

Is TRUE if the termination criterion is positive, and FALSE otherwise.

Usage
TerminatorStagnationHypervolume$is_terminated(archive)
Arguments
archive

(Archive).

Returns

logical(1).


TerminatorStagnationHypervolume$clone()

The objects of this class are cloneable with this method.

Usage
TerminatorStagnationHypervolume$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

See Also

Other Terminator: Terminator, mlr_terminators, mlr_terminators_clock_time, mlr_terminators_combo, mlr_terminators_evals, mlr_terminators_none, mlr_terminators_perf_reached, mlr_terminators_run_time, mlr_terminators_stagnation, mlr_terminators_stagnation_batch

Examples

TerminatorStagnation$new()
trm("stagnation", iters = 5, threshold = 1e-5)

bbotk documentation built on July 17, 2026, 5:07 p.m.