mlr_test_functions: Dictionary of Optimization Test Functions

mlr_test_functionsR Documentation

Dictionary of Optimization Test Functions

Description

A simple mlr3misc::Dictionary storing well-known optimization test functions as ObjectiveRFun objects.

Each objective has two additional fields beyond the standard ObjectiveRFun interface:

  • optimum (numeric(1)) - Known global optimum value (f*).

  • optimum_x (list()) - List of known global optima (each a named list).

For a more convenient way to retrieve test functions, see otfun()/otfuns().

Format

R6::R6Class object inheriting from mlr3misc::Dictionary.

Methods

See mlr3misc::Dictionary.

S3 methods

  • as.data.table(dict, ..., objects = FALSE)
    mlr3misc::Dictionary -> data.table::data.table()
    Returns a data.table::data.table() with fields "key", "label", "dimension", "optimum", and "optimum_x" as columns. If objects is set to TRUE, the constructed objects are returned in the list column named object.

See Also

Sugar functions: otfun(), otfuns()

Examples

as.data.table(mlr_test_functions)
obj = mlr_test_functions$get("branin")
obj$eval(list(x1 = 0, x2 = 0))

bbotk documentation built on April 8, 2026, 9:07 a.m.