Select best subset of points by non dominated sorting with
hypervolume contribution for tie breaking. Works on an arbitrary dimension
of size two or higher.
Non-dominated sorting is computed with moocore::pareto_rank() and
hypervolume contributions with moocore::hv_contributions().
Boundary points, i.e., points that are best in at least one objective within their front,
always survive tie breaking.
nds_selection(points, n_select, ref_point = NULL, minimize = TRUE)Vector of indices of selected points
(matrix())
Numeric matrix with each column corresponding to a point
(integer(1L))
Amount of points to select.
(numeric())
Reference point for hypervolume.
('logical()')
Should the ranking be based on minimization?
Can be specified for each dimension or for all.
Default is TRUE for each dimension.