Learn R Programming

bbotk (version 1.13.0)

optimize_async_default: Default Asynchronous Optimization

Description

Used internally in OptimizerAsync.

Usage

optimize_async_default(
  instance,
  optimizer,
  design = NULL,
  n_workers = NULL,
  profiles = NULL
)

Arguments

instance

OptimInstanceAsync.

optimizer

OptimizerAsync.

design

data.table::data.table()
(Initial) design send to the queue.

n_workers

Number of workers to be started. Defaults to the number of workers set by rush::rush_plan().

profiles

(named integer())
Number of workers to be started on each mirai compute profile, e.g. c(cpu = 2, gpu = 2). Defaults to the profiles set by rush::rush_plan(). Cannot be combined with n_workers.