otfun: Syntactic Sugar for Optimization Test Functions

View source: R/sugar.R

otfunR Documentation

Syntactic Sugar for Optimization Test Functions

Description

This function complements mlr_test_functions with functions in the spirit of mlr_sugar from mlr3.

Usage

otfun(.key, ...)

otfuns(.keys, ...)

Arguments

.key

(character(1))
Key passed to the respective dictionary to retrieve the object.

...

(named list())
Named arguments passed to the constructor. See mlr3misc::dictionary_sugar_get() for more details.

.keys

(character())
Keys passed to the respective dictionary to retrieve multiple objects.

Value

  • ObjectiveRFun for otfun().

  • list of ObjectiveRFun for otfuns().

Examples

obj = otfun("branin")
obj$eval(list(x1 = 1, x2 = 2))

bbotk documentation built on April 8, 2026, 9:07 a.m.