| is_dominated | R Documentation |
Returns which points from a set are dominated by another point in the set.
See moocore::is_nondominated() for details about the implementation.
Points that are equal to each other are all considered non-dominated, i.e. weakly dominated points are kept.
is_dominated(ymat)
ymat |
( |
logical() with TRUE if a point (column of ymat) is dominated.
moocore::is_nondominated()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.