| mlr_terminators_stagnation_hypervolume | R Documentation |
Class to terminate the optimization after the hypervolume stagnates,
i.e. does not improve more than threshold over the last iters iterations.
The hypervolume is computed using moocore::hypervolume().
The reference point is the maximum of each objective over all evaluations.
This Terminator can be instantiated via the
dictionary mlr_terminators or with the associated
sugar function trm():
mlr_terminators$get("stagnation_hypervolume")
trm("stagnation_hypervolume")
itersinteger(1)
Number of iterations to evaluate the performance improvement on, default is 10.
thresholdnumeric(1)
If the improvement is less than threshold, optimization is stopped, default is 0.
Terminator -> TerminatorStagnationHypervolume
TerminatorStagnationHypervolume$new()Creates a new instance of this R6 class.
TerminatorStagnationHypervolume$new()
TerminatorStagnationHypervolume$is_terminated()Is TRUE if the termination criterion is positive, and FALSE otherwise.
TerminatorStagnationHypervolume$is_terminated(archive)
archive(Archive).
logical(1).
TerminatorStagnationHypervolume$clone()The objects of this class are cloneable with this method.
TerminatorStagnationHypervolume$clone(deep = FALSE)
deepWhether to make a deep clone.
Other Terminator:
Terminator,
mlr_terminators,
mlr_terminators_clock_time,
mlr_terminators_combo,
mlr_terminators_evals,
mlr_terminators_none,
mlr_terminators_perf_reached,
mlr_terminators_run_time,
mlr_terminators_stagnation,
mlr_terminators_stagnation_batch
TerminatorStagnation$new()
trm("stagnation", iters = 5, threshold = 1e-5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.