| mlr_test_functions | R Documentation |
A simple mlr3misc::Dictionary storing well-known optimization test functions as ObjectiveRFun objects.
Each objective has two additional fields beyond the standard ObjectiveRFun interface:
optimum (numeric(1)) - Known global optimum value (f*).
optimum_x (list()) - List of known global optima (each a named list).
For a more convenient way to retrieve test functions, see otfun()/otfuns().
R6::R6Class object inheriting from mlr3misc::Dictionary.
See mlr3misc::Dictionary.
as.data.table(dict, ..., objects = FALSE)
mlr3misc::Dictionary -> data.table::data.table()
Returns a data.table::data.table() with fields "key", "label", "dimension",
"optimum", and "optimum_x" as columns.
If objects is set to TRUE, the constructed objects are returned in the list column named object.
Sugar functions: otfun(), otfuns()
as.data.table(mlr_test_functions)
obj = mlr_test_functions$get("branin")
obj$eval(list(x1 = 0, x2 = 0))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.