Used internally in OptimizerAsync.
optimize_async_default(
instance,
optimizer,
design = NULL,
n_workers = NULL,
profiles = NULL
)OptimInstanceAsync.
OptimizerAsync.
data.table::data.table()
(Initial) design send to the queue.
Number of workers to be started.
Defaults to the number of workers set by rush::rush_plan().
(named integer())
Number of workers to be started on each mirai compute profile, e.g. c(cpu = 2, gpu = 2).
Defaults to the profiles set by rush::rush_plan().
Cannot be combined with n_workers.