Learn R Programming

bbotk (version 1.10.0)

otfun: Syntactic Sugar for Optimization Test Functions

Description

This function complements mlr_test_functions with functions in the spirit of mlr_sugar from mlr3.

Usage

otfun(.key, ...)

otfuns(.keys, ...)

Value

  • ObjectiveRFun for otfun().

  • list of ObjectiveRFun for otfuns().

Arguments

.key

(character(1))
Key passed to the respective dictionary to retrieve the object.

...

(named list())
Named arguments passed to the constructor. See mlr3misc::dictionary_sugar_get() for more details.

.keys

(character())
Keys passed to the respective dictionary to retrieve multiple objects.

Examples

Run this code
obj = otfun("branin")
obj$eval(list(x1 = 1, x2 = 2))

Run the code above in your browser using DataLab