powered by
This function complements mlr_test_functions with functions in the spirit of mlr_sugar from mlr3.
mlr_sugar
otfun(.key, ...)otfuns(.keys, ...)
otfuns(.keys, ...)
ObjectiveRFun for otfun().
otfun()
list of ObjectiveRFun for otfuns().
otfuns()
(character(1)) Key passed to the respective dictionary to retrieve the object.
character(1)
(named list()) Named arguments passed to the constructor. See mlr3misc::dictionary_sugar_get() for more details.
list()
mlr3misc::dictionary_sugar_get()
(character()) Keys passed to the respective dictionary to retrieve multiple objects.
character()
obj = otfun("branin") obj$eval(list(x1 = 1, x2 = 2))
Run the code above in your browser using DataLab